@@ -45,7 +45,7 @@ func New(host environment.HostActions) environment.VM {
 const (
 	envLimaInstance = "LIMA_INSTANCE"
 	lima            = "lima"
-	limactl         = limautil.Limactl
+	limactl         = limautil.LimactlCommand
 )
 
 func (l limaVM) limaConfFile() string {
@@ -324,8 +324,10 @@ func (l *limaVM) addPostStartActions(a *cli.ActiveCommandChain, conf config.Conf
 	a.Add(func() error {
 		if !l.limaConf.Rosetta.Enabled {
 			// use binfmt when rosetta is disabled and emulation is disabled i.e. host arch
-			if environment.HostArch() == environment.Arch(conf.Arch).Value() {
-				return core.SetupBinfmt(l.host, l, environment.Arch(conf.Arch))
+			if arch := environment.HostArch(); arch == environment.Arch(conf.Arch).Value() {
+				if err := core.SetupBinfmt(l.host, l, environment.Arch(conf.Arch)); err != nil {
+					logrus.Warn(fmt.Errorf("unable to enable qemu %s emulation: %w", arch, err))
+				}
 			}
 
 			// rosetta is disabled
